package amine.bou.plugins

import amine.bou.controllers.HabitController
import amine.bou.controllers.HabitOccurrenceController
import amine.bou.models.HabitOccurrenceView
import amine.bou.models.HabitView
import io.ktor.server.application.*
import io.ktor.server.request.*
import io.ktor.server.resources.Resources
import io.ktor.server.response.*
import io.ktor.server.routing.*
import java.lang.Long.parseLong

fun Application.configureRouting() {
    val habitController = HabitController()
    val habitOccurrenceController = HabitOccurrenceController()
    install(Resources)
    routing {
        route("/habits") {
            get {
                call.respond(habitController.getAllHabits())
            }

            post {
                call.respond(habitController.createHabit(call.receive<HabitView>()))
            }

            route("/{id}") {
                get {
                    call.respond(habitController.getOneHabit(Integer.parseInt(call.parameters["id"])))
                }

                put {
                    call.respond(habitController.updateHabit(Integer.parseInt(call.parameters["id"]), call.receive<HabitView>()))
                }

                delete {
                    call.respond(habitController.deleteHabit(Integer.parseInt(call.parameters["id"])))
                }

                post("/occurrence") {
                    call.respond(habitOccurrenceController.createOccurrence(Integer.parseInt(call.parameters["id"]), call.receive<HabitOccurrenceView>()))
                }

                delete("/occurrence/{occId}") {
                    call.respond(habitOccurrenceController.deleteOccurrence(Integer.parseInt(call.parameters["id"]), parseLong(call.parameters["occId"])))
                }
            }
        }

    }
}
